@@ -94,10 +94,15 @@ class PackageBuild:
 
     def git_clean(self):
         """
-        git build
+        git clean
         """
         logger.info('{} clean'.format(self.name))
-        run_shell_list(['git gc --aggressive'])
+        run_shell_list([
+            'git rm -r --cached .',
+            'git add .',
+            "git commit -m 'update .gitignore'",
+            'git gc --aggressive'
+        ])
 
 
 def command_line_parser():
@@ -121,5 +126,7 @@ def notebuild():
         package.git_install()
     elif args.command == 'build':
         package.git_build()
+    elif args.command == 'clean':
+        package.git_clean()
     elif args.command == 'clean_history':
         package.git_clean_history()
